==> atlas-generic-3.10.2-0.tar.bz2: include/atlas/atlas_buildinfo.h <==
#ifndef ATL_INSTINFO_H
   #define ATL_INSTINFO_H

#define ATL_ARCH "Core264SSE3"
#define ATL_INSTFLAGS "-1 0 -a 1 -l 1"
#define ATL_F2CDEFS "-DAdd_ -DF77_INTEGER=int -DStringSunStyle"
#define ATL_ARCHDEFS "-DATL_OS_Linux -DATL_ARCH_Core2 -DATL_CPUMHZ=2900 -DATL_SSE3 -DATL_SSE2 -DATL_SSE1 -DATL_USE64BITS -DATL_GAS_x8664"
#define ATL_DKCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_DKC "/usr/bin/gcc"
#define ATL_SKCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_SKC "/usr/bin/gcc"
#define ATL_DMCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_DMC "/usr/bin/gcc"
#define ATL_SMCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_SMC "/usr/bin/gcc"
#define ATL_ICCFLAGS "-DL2SIZE=4194304 -I/srv/iraf/bldtmp/porcelain.bznhqrYPVU/porcelain/conda-bld/work/ATLAS/build/include -I/srv/iraf/bldtmp/porcelain.bznhqrYPVU/porcelain/conda-bld/work/ATLAS/build/..//include -I/srv/iraf/bldtmp/porcelain.bznhqrYPVU/porcelain/conda-bld/work/ATLAS/build/..//include/contrib -DAdd_ -DF77_INTEGER=int -DStringSunStyle -DATL_OS_Linux -DATL_ARCH_Core2 -DATL_CPUMHZ=2900 -DATL_SSE3 -DATL_SSE2 -DATL_SSE1 -DATL_USE64BITS -DATL_GAS_x8664 -m64 -DATL_DYLIBS -DATL_FULL_LAPACK -DATL_NCPU=4 -fomit-frame-poin"
#define ATL_ICC "/usr/bin/gcc"
#define ATL_F77FLAGS "-O -msse3 -m64 -fPIC"
#define ATL_F77 "/usr/bin/gfortran"
#define ATL_DKCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SKCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_DMCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SMCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_ICCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_F77VERS "GNU Fortran (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SYSINFO "Linux nott.stsci.edu 2.6.32-642.4.2.el6.x86_64 #1 SMP Mon Aug 15 02:06:41 EDT 2016 x86_64 x86_64 x86_64 GNU/Linux"
#define ATL_DATE    "Wed Oct 12 14:00:54 EDT 2016"
#define ATL_UNAM    "iraf"
#define ATL_VERS    "3.10.2"

#endif

==> atlas-generic-3.10.2-1.tar.bz2: include/atlas/atlas_buildinfo.h <==
#ifndef ATL_INSTINFO_H
   #define ATL_INSTINFO_H

#define ATL_ARCH "Core264SSE3"
#define ATL_INSTFLAGS "-1 0 -a 1 -l 1"
#define ATL_F2CDEFS "-DAdd_ -DF77_INTEGER=int -DStringSunStyle"
#define ATL_ARCHDEFS "-DATL_OS_Linux -DATL_ARCH_Core2 -DATL_CPUMHZ=2900 -DATL_SSE3 -DATL_SSE2 -DATL_SSE1 -DATL_USE64BITS -DATL_GAS_x8664"
#define ATL_DKCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_DKC "/usr/bin/gcc"
#define ATL_SKCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_SKC "/usr/bin/gcc"
#define ATL_DMCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_DMC "/usr/bin/gcc"
#define ATL_SMCFLAGS "-fomit-frame-pointer -mfpmath=sse -O2 -msse3 -m64 -fPIC"
#define ATL_SMC "/usr/bin/gcc"
#define ATL_ICCFLAGS "-DL2SIZE=4194304 -I/srv/iraf/miniconda3/conda-bld/atlas-generic_1476319176928/work/ATLAS/build/include -I/srv/iraf/miniconda3/conda-bld/atlas-generic_1476319176928/work/ATLAS/build/..//include -I/srv/iraf/miniconda3/conda-bld/atlas-generic_1476319176928/work/ATLAS/build/..//include/contrib -DAdd_ -DF77_INTEGER=int -DStringSunStyle -DATL_OS_Linux -DATL_ARCH_Core2 -DATL_CPUMHZ=2900 -DATL_SSE3 -DATL_SSE2 -DATL_SSE1 -DATL_USE64BITS -DATL_GAS_x8664 -m64 -DATL_DYLIBS -DATL_FULL_LAPACK -DATL_NCPU=4 -fomit-frame-p"
#define ATL_ICC "/usr/bin/gcc"
#define ATL_F77FLAGS "-O -msse3 -m64 -fPIC"
#define ATL_F77 "/usr/bin/gfortran"
#define ATL_DKCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SKCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_DMCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SMCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_ICCVERS "gcc (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_F77VERS "GNU Fortran (GCC) 4.4.7 20120313 (Red Hat 4.4.7-17)"
#define ATL_SYSINFO "Linux nott.stsci.edu 2.6.32-642.4.2.el6.x86_64 #1 SMP Mon Aug 15 02:06:41 EDT 2016 x86_64 x86_64 x86_64 GNU/Linux"
#define ATL_DATE    "Wed Oct 12 20:39:46 EDT 2016"
#define ATL_UNAM    "iraf"
#define ATL_VERS    "3.10.2"

#endif
